<?php

namespace Laraautos\Favourite\Providers;

use Illuminate\Support\ServiceProvider;
use Laraautos\Favourite\Favourite;

class FavouriteServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = true;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'favourite');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'favourite');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();

        $this->app->register(\Laraautos\Favourite\Providers\AuthServiceProvider::class);
        $this->app->register(\Laraautos\Favourite\Providers\RouteServiceProvider::class);
        // $this->app->register(\Laraautos\Favourite\Providers\EventServiceProvider::class);
        // $this->app->register(\Laraautos\Favourite\Providers\WorkflowServiceProvider::class);
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->bind('laraautos.favourite', function($app)
        {
            return $this->app->make(Favourite::class);
        });
    }

    /**
     * Register the bindings for the service provider.
     *
     * @return void
     */
    public function registerBindings() {
                // Bind Favourite to repository
        $this->app->bind(
            'Laraautos\Favourite\Interfaces\FavouriteRepositoryInterface',
            \Laraautos\Favourite\Repositories\Eloquent\FavouriteRepository::class
        );
    }


    /**
     * Merges user's and favourite's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'laraautos.favourite'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                \Laraautos\Favourite\Commands\Favourite::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['laraautos.favourite'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('laraautos/favourite.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/favourite')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/favourite')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
